@@ -2,6 +2,7 @@ from jnius import autoclass, cast
 from utils import *
 import pandas as pd
 import numpy as np
+from pyterrier import properties as props
 
 class BatchRetrieve:
     default_controls={
@@ -30,100 +31,62 @@ class BatchRetrieve:
         self.IndexRef=indexRef
         self.appSetup = autoclass('org.terrier.utility.ApplicationSetup')
 
-        if properties==None:
-            self.properties=self.default_properties
-        else:
-            self.properties=properties
+        self.properties=self.default_properties.copy()
+        if type(properties)==type({}):
+            for key,value in properties.items():
+                self.properties[key]=value
 
-        props = autoclass('java.util.Properties')()
-        for control,value in self.properties.items():
-            props.put(control,value)
+        for key,value in self.properties.items():
+            props.put(key,value)
         self.appSetup.bootstrapInitialisation(props)
 
-        if controls==None:
-            self.controls=self.default_controls
-        else:
-            self.controls=controls
+        self.controls=self.default_controls.copy()
+        if type(controls)==type({}):
+            for key,value in controls.items():
+                self.controls[key]=value
 
         MF = autoclass('org.terrier.querying.ManagerFactory')
-        print(MF)
-        print(indexRef)
         self.ManagerFactory = MF._from_(indexRef)
 
     def transform(self,queries):
         results=[]
         queries=Utils.form_dataframe(queries)
         for index,row in queries.iterrows():
+            rank = 0
             srq = self.ManagerFactory.newSearchRequest(row['qid'],row['query'])
             for control,value in self.controls.items():
                 srq.setControl(control,value)
             self.ManagerFactory.runSearchRequest(srq)
             result=srq.getResults()
             for item in result:
-                res = [queries.iloc[index]['qid'],item.getMetadata("docno"),item.getScore()]
+                res = [row['qid'],item.getMetadata("docno"),rank,item.getScore()]
+                rank += 1
+                # res = [queries.iloc[index]['qid'],item.getMetadata("docno"),item.getScore()]
                 results.append(res)
-        res_dt=pd.DataFrame(results,columns=['qid','docno','score'])
-        self.lastResult=res_dt
+        res_dt=pd.DataFrame(results,columns=['qid','docno','rank','score'])
         return res_dt
 
     def saveResult(self, result, path):
         res_copy = result.copy()
         res_copy.insert(1, "Q0", "Q0")
-        res_copy.insert(4, "wmodel", self.controls["wmodel"])
+        res_copy.insert(5, "wmodel", self.controls["wmodel"])
         res_copy.to_csv(path, sep=" ", header=False, index=False)
 
-    def saveLastResult(self, path):
-        self.saveResult(self.lastResult,path)
-
     def setControls(self, controls):
-        self.controls=controls
+        for key, value in controls:
+            self.controls[key]=value
 
     def setControl(self, control,value):
         self.controls[control]=value
 
 
 class FeaturesBatchRetrieve(BatchRetrieve):
-    default_controls={
-        "terrierql": "on",
-        "parsecontrols": "on",
-        "parseql": "on",
-        "applypipeline": "on",
-        "localmatching": "on",
-        "filters": "on",
-        "decorate":"on",
-        "wmodel": "DPH",
-        "matching": "FatFeaturedScoringMatching,org.terrier.matching.daat.FatFull"
-    }
-    default_properties={
-        "querying.processes":"terrierql:TerrierQLParser,parsecontrols:TerrierQLToControls,parseql:TerrierQLToMatchingQueryTerms,matchopql:MatchingOpQLParser,applypipeline:ApplyTermPipeline,localmatching:LocalManager$ApplyLocalMatching,qe:QueryExpansion,labels:org.terrier.learning.LabelDecorator,filters:LocalManager$PostFilterProcess",
-        "querying.postfilters": "decorate:SimpleDecorate,site:SiteFilter,scope:Scope",
-        "querying.default.controls": "wmodel:DPH,parsecontrols:on,parseql:on,applypipeline:on,terrierql:on,localmatching:on,filters:on,decorate:on",
-        "querying.allowed.controls": "scope,qe,qemodel,start,end,site,scope",
-        "termpipelines": "Stopwords,PorterStemmer"
-    }
+    default_controls = BatchRetrieve.default_controls
+    default_controls["matching"] = "FatFeaturedScoringMatching,org.terrier.matching.daat.FatFull"
+    default_properties = BatchRetrieve.default_properties
     def __init__(self, indexPath, features, controls=None, properties=None):
-        JIR = autoclass('org.terrier.querying.IndexRef')
-        indexRef = JIR.of(indexPath)
-
-        self.IndexRef=indexRef
-        self.appSetup = autoclass('org.terrier.utility.ApplicationSetup')
-
-        if properties==None:
-            self.properties=self.default_properties
-        else:
-            self.properties=properties
-        self.properties["fat.featured.scoring.matching.features"]=";".join(features)
-        props = autoclass('java.util.Properties')()
-        for control,value in self.properties.items():
-            props.put(control,value)
-        self.appSetup.bootstrapInitialisation(props)
-        if controls==None:
-            self.controls=self.default_controls
-        else:
-            self.controls=controls
-        MF = autoclass('org.terrier.querying.ManagerFactory')
-        self.ManagerFactory = MF._from_(indexRef)
-
+        props.put("fat.featured.scoring.matching.features",";".join(features))
+        super().__init__(indexPath,controls=controls,properties=properties)
 
     def transform(self,topics):
         results=[]
